# gwchirp

Gravitational Waveforms in python

## Installation

### Setup env

```
conda env create -f environment.yaml
```

 - I did `conda create -n chirpy-dev python=3.7` then `conda install` other deps.
 - Save environment with `conda env export > environment.yaml`